@@ -16,7 +16,7 @@
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
 
- $Id: rcube_template.php 4763 2011-05-13 17:31:09Z alec $
+ $Id: rcube_template.php 5061 2011-08-12 19:39:39Z thomasb $
 
  */
 
@@ -249,11 +249,16 @@ class rcube_template extends rcube_html_page
     public function show_message($message, $type='notice', $vars=null, $override=true)
     {
         if ($override || !$this->message) {
+            if (rcube_label_exists($message)) {
+                if (!empty($vars))
+                    $vars = array_map('Q', $vars);
+                $msgtext = rcube_label(array('name' => $message, 'vars' => $vars));
+            }
+            else
+                $msgtext = $message;
+
             $this->message = $message;
-            $this->command(
-                'display_message',
-                rcube_label(array('name' => $message, 'vars' => $vars)),
-                $type);
+            $this->command('display_message', $msgtext, $type, $timeout * 1000);
         }
     }
 
